## $Id: interfaces.py 7321 2011-12-10 06:15:17Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Interfaces of access code related components.
"""
from zope import schema
from zope.interface import Interface
from waeup.sirp.interfaces import ISIRPObject

class IAccessCode(ISIRPObject):
    """An access code.
    """
    batch_serial = schema.Int(
        title = u'Serial number inside batch',
        )
    batch_prefix = schema.TextLine(
        title = u'Prefix inside batch',
        )
    batch_num = schema.Int(
        title = u'Batch number',
        )
    random_num = schema.TextLine(
        title = u'Random part of access code.',
        )
    cost = schema.Float(
        title = u'Cost of access code',
        default = 0.0, min = 0.0,
        )
    state = schema.TextLine(
        title = u'Workflow state',
        )
    representation = schema.TextLine(
        title = u'Complete title of access code',
        )
    owner = schema.TextLine(
        title = u'Purchaser',
        )
    history = schema.Text(
        title = u'The history of access code as lines',
        default = u'',
        readonly = True,
       )

class IAccessCodeBatch(Interface):
    """A factory for batches of access codes.
    """
    creation_date = schema.Date(
        title = u'Creation date',
        )
    creator = schema.TextLine(
        title = u'Batch creator',
        )
    prefix = schema.TextLine(
        title = u'Batch prefix',
        )
    num = schema.Int(
        title = u'Batch number (1-3 digits)',
        min = 0, max = 999,
        )
    entry_num = schema.Int(
        title = u'Number of access codes',
        default = 1000, min = 0,
        )
    cost = schema.Float(
        title = u'Cost of access code',
        default = 0.0, min = 0.0,
        )
    disabled_num = schema.Int(
        title = u'Number of disabled access codes inside the batch',
        default = 0,
        readonly = True,
        )
    used_num = schema.Int(
        title = u'Number of used access codes inside the batch',
        default = 0,
        readonly = True,
        )

class IAccessCodeBatchContainer(ISIRPObject):
    """A container for access code batches.
    """

    def addBatch(batch):
        """Add a batch.
        """
